@@ -249,7 +249,7 @@ ls_iconbox_get_children (LSIconBox * plsib)
 void
 ls_iconbox_set_size (LSIconBox * plsib, glong lSize)
 {
-    int size = lsIconSize[lSize] + 2 * lsBorderWidth;
+    int size = lsIconSize[lSize] + lsBorderWidth;
 
     plsib->priv->lSize = lSize;
 
